@@ -42,7 +42,7 @@
 #define HAVE_HEIF 1
 
 /* The Eigen3 version string, if found, or an empty string otherwise */
-#define EIGEN3_VERSION_STRING "3.4.0"
+#define EIGEN3_VERSION_STRING ""
 
 /* Define to 1 if GPhoto2 shared library is installed */
 #define HAVE_GPHOTO2 1
@@ -111,3 +111,10 @@
 #define HAVE_IMAGE_MAGICK 1
 
 #define LIBEXEC_INSTALL_DIR "/usr/libexec"
+
+#define CMAKE_VERSION_STRING        "4.1.2"
+#define CMAKE_CXX_COMPILER_ID       "GNU"
+#define CMAKE_CXX_COMPILER_VERSION  "14.2.1"
+#define CMAKE_HOST_PRETTY_NAME      "Arch Linux ARM"
+#define CMAKE_SYSTEM_PROCESSOR      "aarch64"
+#define CMAKE_HOST_SYSTEM_PROCESSOR "aarch64"
